@@ -11,10 +11,14 @@ from pybk8500.parser import Parser
 
 __all__ = [
     'Message', 'CC_Commands', 'CV_Commands', 'CW_Commands', 'CR_Commands',
-    'CommandStatus', 'SetRemoteOperation', 'LoadSwitch', 'SetMaxVoltage', 'ReadMaxVoltage', 'SetMaxCurrent',
-    'ReadMaxCurrent', 'SetMaxPower', 'ReadMaxPower', 'SetMode', 'ReadMode', 'SetCCModeCurrent', 'ReadCCModeCurrent',
-    'SetCVModeVoltage', 'ReadCVModeVoltage', 'SetCWModePower', 'ReadCWModePower', 'SetCRModeResistance',
-    'ReadCRModeResistance', 'SetCCModeTransientCurrentAndTiming', 'ReadCCModeTransientParameters',
+    'CommandStatus', 'SetRemoteOperation', 'RemoteOn', 'RemoteOff', 'LoadSwitch', 'LoadOn', 'LoadOff',
+    'SetMaxVoltage', 'ReadMaxVoltage', 'SetMaxCurrent', 'ReadMaxCurrent', 'SetMaxPower', 'ReadMaxPower',
+    'SetMode', 'ReadMode',
+    'CC', 'SetCCModeCurrent', 'ReadCCModeCurrent', 'SetModeCurrent', 'ReadModeCurrent',
+    'CV', 'SetCVModeVoltage', 'ReadCVModeVoltage', 'SetModeVoltage', 'ReadModeVoltage',
+    'CW', 'SetCWModePower', 'ReadCWModePower', 'SetModePower', 'ReadModePower',
+    'CR', 'SetCRModeResistance', 'ReadCRModeResistance', 'SetModeResistance', 'ReadModeResistance',
+    'SetCCModeTransientCurrentAndTiming', 'ReadCCModeTransientParameters',
     'SetCVModeTransientVoltageAndTiming', 'ReadCVModeTransientParameters', 'SetCWModeTransientPowerAndTiming',
     'ReadCWModeTransientParameters', 'SetCRModeTransientResistanceAndTiming', 'ReadCRModeTransientParameters',
     'SelectListOperation', 'ReadListOperation', 'SetHowListsRepeat', 'ReadHowListsRepeat', 'SetNumberOfSteps',
@@ -35,6 +39,7 @@ class Message(bytearray):
     NAME = 'Base Command'
 
     RESPONSE_TYPE = None
+    REPR_EXCLUDE = []
 
     MSG_LENGTH = 26
 
@@ -75,16 +80,19 @@ class Message(bytearray):
         # Create get_value function for
         if isinstance(self, Message):
             # Is instance object with values
+            cls = self.__class__
             get_value = lambda name: getattr(self, name, None)
         else:
             # Was called as a classmethod, so there are no values
+            cls = self
             get_value = lambda name: None
 
         # Populate the fields
-        for name in dir(self):
-            f = getattr(self, name, None)
-            if isinstance(f, Field) and f.name == name:
-                fields[name] = get_value(name)
+        for name in dir(cls):
+            if not name.startswith('_'):
+                f = getattr(cls, name, None)
+                if isinstance(f, Field) and f.name == name:
+                    fields[name] = get_value(name)
 
         return fields
 
@@ -142,6 +150,14 @@ class Message(bytearray):
         # bytearray has no super().__bytes___() I'm guessing most efficient is iter
         return bytes(iter(self))
 
+    def __repr__(self):
+        field_str = ', '.join(("{}={}".format(name, repr(value)) for name, value in self.fields().items()
+                               if name not in self.REPR_EXCLUDE))
+        return '{}({})'.format(self.__class__.__name__, field_str)
+
+    def __str__(self):
+        return self.__repr__()
+
 
 @Parser.add_lookup
 class CommandStatus(Message):
@@ -162,12 +178,15 @@ class CommandStatus(Message):
     status.set_converter = STATUS_NAMES.get
     value = status  # Alias so Message(value=1) can be used
 
+Message.RESPONSE_TYPE = CommandStatus
+
 
 @Parser.add_lookup
 class SetRemoteOperation(Message):
     """Set the DC Load to remote operation"""
     ID = 0x20
     NAME = 'Set Remote Operation'
+    RESPONSE_TYPE = CommandStatus
 
     OPERATION_NAMES = {'Front Panel': 0, 'Remote': 1}
     OPERATION_VALUES = {v: k for k, v in OPERATION_NAMES.items()}
@@ -178,6 +197,24 @@ class SetRemoteOperation(Message):
     value = operation  # Alias so Message(value=1) can be used
 
 
+class RemoteOn(SetRemoteOperation):
+    NAME = 'Remote On'
+
+    def __init__(self, *args, **kwargs):
+        if 'value' not in kwargs and 'operation' not in kwargs:
+            kwargs['value'] = 1
+        super().__init__(*args, **kwargs)
+
+
+class RemoteOff(SetRemoteOperation):
+    NAME = 'Remote Off'
+
+    def __init__(self, *args, **kwargs):
+        if 'value' not in kwargs and 'operation' not in kwargs:
+            kwargs['value'] = 0
+        super().__init__(*args, **kwargs)
+
+
 @Parser.add_lookup
 class LoadSwitch(Message):
     """Load switch to turn the load on or off"""
@@ -193,6 +230,24 @@ class LoadSwitch(Message):
     value = operation  # Alias so Message(value=1) can be used
 
 
+class LoadOn(LoadSwitch):
+    NAME = 'Load On'
+
+    def __init__(self, *args, **kwargs):
+        if 'value' not in kwargs and 'operation' not in kwargs:
+            kwargs['value'] = 1
+        super().__init__(*args, **kwargs)
+
+
+class LoadOff(LoadSwitch):
+    NAME = 'Load Off'
+
+    def __init__(self, *args, **kwargs):
+        if 'value' not in kwargs and 'operation' not in kwargs:
+            kwargs['value'] = 0
+        super().__init__(*args, **kwargs)
+
+
 @Parser.add_lookup
 class SetMaxVoltage(Message):
     """Set the maximum voltage allowed"""
@@ -291,6 +346,11 @@ class ReadCCModeCurrent(SetCCModeCurrent):
     NAME = 'Read CC Mode Current'
 
 
+CC = SetCCModeCurrent
+SetModeCurrent = SetCCModeCurrent
+ReadModeCurrent = ReadCCModeCurrent
+
+
 @Parser.add_lookup
 class SetCVModeVoltage(Message):
     """Set CV mode voltage"""
@@ -309,6 +369,11 @@ class ReadCVModeVoltage(SetCVModeVoltage):
     NAME = 'Read CV Mode Voltage'
 
 
+CV = SetCVModeVoltage
+SetModeVoltage = SetCVModeVoltage
+ReadModeVoltage = ReadCVModeVoltage
+
+
 @Parser.add_lookup
 class SetCWModePower(Message):
     """Set CW mode power"""
@@ -327,6 +392,11 @@ class ReadCWModePower(SetCWModePower):
     NAME = 'Read CW Mode Power'
 
 
+CW = SetCVModeVoltage
+SetModePower = SetCWModePower
+ReadModePower = ReadCWModePower
+
+
 @Parser.add_lookup
 class SetCRModeResistance(Message):
     """Set CR mode resistance"""
@@ -345,6 +415,11 @@ class ReadCRModeResistance(SetCRModeResistance):
     NAME = 'Read CR Mode Resistance'
 
 
+CR = SetCRModeResistance
+SetModeResistance = SetCRModeResistance
+ReadModeResistance = ReadCRModeResistance
+
+
 @Parser.add_lookup
 class SetCCModeTransientCurrentAndTiming(Message):
     """Set CC mode transient current and timing
@@ -931,6 +1006,8 @@ class ReadInputVoltageCurrentPowerState(Message):
     ID = 0x5F
     NAME = 'Read Input Voltage Current Power State'
 
+    REPR_EXCLUDE = ['operation_register', 'demand_register']
+
     # 3 to 6 4 byte little-endian integer for terminal voltage in units of 1 mV
     voltage = ScalarFloatField('voltage', 3, length=4, scalar=1000)  # 1 mV
 
@@ -954,7 +1031,7 @@ class ReadInputVoltageCurrentPowerState(Message):
                                           })
 
     # 16 to 17 2 byte little-endian integer for demand state register (see bit list below)
-    demand_register = BitFlagField('operation_register', 16, length=2,
+    demand_register = BitFlagField('demand_register', 16, length=2,
                                    flags={
                                        'reversed_voltage': 0,  # 0 Reversed voltage is at instrument's terminals (1 means yes)
                                        'over_voltage': 1,  # 1 Over voltage (1 means yes)
